@@ -12,6 +12,7 @@
 #include "service.hpp"
 #include "config.hpp"
 #include "raw_disk_io.hpp"
+#include "log.hpp"
 
 int main(int argc, char **argv)
 {
@@ -50,10 +51,14 @@ int main(int argc, char **argv)
 	ezio::gRPCService service(daemon);
 	service.start(current_config.listen_address);
 
+	// start log
+	ezio::log log(daemon);
+
 	std::cout << "Server listening on " << current_config.listen_address << std::endl;
 	daemon.wait(10);
 	std::cout << "shutdown in main" << std::endl;
 
+	log.join();
 	service.stop();
 
 	return 0;
